@@ -3,13 +3,13 @@ package Crypt::Perl;
 use strict;
 use warnings;
 
-our $VERSION = '0.17_1';
+our $VERSION = '0.31_01';
 
 =encoding utf-8
 
 =head1 NAME
 
-Crypt::Perl - Cryptography in Pure Perl
+Crypt::Perl - Cryptography in pure Perl
 
 =head1 DESCRIPTION
 
@@ -35,7 +35,10 @@ See submodules for usage examples of:
 
 =item * L<JWK thumbprints|https://tools.ietf.org/html/rfc7638>
 
-=item * Certificate Signing Request (CSR) generation (PKCS #10), using RSA or ECDSA (L<Crypt::Perl::PKCS10>)
+=item * Certificate Signing Request (PKCS #10) generation (L<Crypt::Perl::PKCS10>)
+
+=item * SSL/TLS certificate (X.509) generation (L<Crypt::Perl::X509v3>), including
+a broad variety of extensions
 
 =back
 
@@ -47,6 +50,8 @@ See submodules for usage examples of:
 
 =item * L<ECDSA|Crypt::Perl::ECDSA>
 
+=item * L<Ed25519|Crypt::Perl::Ed25519>
+
 =back
 
 =head1 SECURITY
@@ -70,8 +75,11 @@ Caveat emptor.
 RSA key generation is slow—too slow, probably, unless you have
 L<Math::BigInt::GMP> or L<Math::BigInt::Pari> (either of which requires XS).
 It’s one application where pure-Perl cryptography just doesn’t seem
-feasible. :-( Everything else, though, including all ECDSA operations,
-should be fine.
+feasible. :-( Everything else, though, including all ECDSA and Ed25519
+operations, should be fine.
+
+Note that this distribution’s test suite is pretty slow without an
+XS backend.
 
 =head1 TODO
 
@@ -98,7 +106,9 @@ Most of the tests depend on the near-ubiquitous L<OpenSSL|http://openssl.org>,
 without which the Internet would be a very, very different reality from
 what we know!
 
-Other parts are parted from L<LibTomCrypt|http://www.libtom.net>.
+The Ed25519 logic is ported from L<forge.js|https://github.com/digitalbazaar/forge/blob/master/lib/ed25519.js>.
+
+Other parts are ported from L<LibTomCrypt|http://www.libtom.net>.
 
 =head1 LICENSE
 
